const fetch = require("isomorphic-fetch")
// authentication url
const authUrl = process.env.AUTH_URL
// create basic authentication with id and secret
const basicAuth = Buffer.from(`${process.env.MW_RISK_API_PROD_APP_CLIENTID}:${process.env.MW_RISK_API_PROD_APP_SECRET}`).toString('base64')
// get access token from authentication server
const doc = await fetch(authUrl, {
  headers: {
    Authorization: `Basic ${basicAuth}`,
    'Content-Type': 'application/json'
  },
  method: 'POST'
}).then(res => res.json())
const accessToken = doc.access_token
console.log('access token', accessToken)
;

const { pluck, prop, map } = require('ramda')
const patientId = 'smart-1685497'
const patient = await fetch('https://r2.smarthealthit.org/Patient/' + patientId)
.then(res => res.json())
.then(patient => ({resource: patient}))
const medications = await fetch('https://r2.smarthealthit.org/MedicationOrder?patient=' + patientId)
  .then(res => res.json())
  .then(bundle => pluck('resource', prop('entry', bundle)))
  .then(pluck('medicationCodeableConcept'))
  .then(map(med => ({resource: { resourceType: 'Medication', code: med }})))

JSON.stringify(medications, null, 2);

const bundle = {
  resourceType: 'Bundle',
  type: 'collection',
  
  entry: [
    patient,
    ...medications
  ]
}
JSON.stringify(bundle, null, 2);


const result = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles`, {
  method: 'POST',
  headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  },
  body: JSON.stringify(bundle)
}).then(res => res.json())

const profileId = result.id

result;

const score = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/riskscore`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
score.html;
const matrix = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/matrix`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
matrix.html;
const riskFactors = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/risk-factors`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
riskFactors.html;
const adverseEffects = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/adverse-effects`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
adverseEffects.html;

const scoreData = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/scoredata`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
  scoreData;

const allScoreData = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}/allscoredata`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
    JSON.stringify(allScoreData, null, 2);

const cachedBundle = await fetch(`${process.env.MEDWISE_RISK_API_URL}/profiles/${result.id}`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
cachedBundle;
